==> 0.0.21.tar.gz: lib/webview_container_new.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter_threatmetrix_module/flutter_threatmetrix_module.dart';
import 'package:paydala_flutter_sdk/webchannel_payload.dart';
import 'package:webview_flutter_android/webview_flutter_android.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'package:permission_handler/permission_handler.dart';

class WebViewExample extends StatefulWidget {
  const WebViewExample ({Key? key, required this.url}): super(key: key);
  final String url;

  @override
  State<WebViewExample> createState() => _WebViewExampleState();
}

class _WebViewExampleState extends State<WebViewExample> {
  late final WebViewController controller;

  @override
  void initState() {
    super.initState();
    controller = WebViewController()
      ..setJavaScriptMode(JavaScriptMode.unrestricted)
      ..loadRequest(Uri.parse(widget.url));

    final platformController = controller.platform;
    if (platformController is AndroidWebViewController) {
      platformController.setGeolocationPermissionsPromptCallbacks(
        onShowPrompt: (request) async {
          // request location permission
          final locationPermissionStatus = await Permission.locationWhenInUse.request();

          // return the response
          return GeolocationPermissionsResponse(
            allow: locationPermissionStatus == PermissionStatus.granted,
            retain: false,
          );
        },
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: WebViewWidget(
        controller: controller,
      ),
    );
  }

  Future<void> getProfilingData(String sessionId) async {
    String profileData = 'No Data';
    String? error;
    String orgId = '52whdrrv';
    String fpServer = 'h-sdk.online-metrix.net';

    try {
      final result = await FlutterThreatmetrixModule()
              .getProfilingData(sessionId, orgId, fpServer) ??
          'No Data';
      profileData = result;
    } catch (e) {
      error = e.toString();
    }
  }
}

==> 0.0.27.tar.gz: lib/webview_container_new.dart <==
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter_threatmetrix_module/flutter_threatmetrix_module.dart';
import 'package:paydala_flutter_sdk/webchannel_payload.dart';
import 'package:webview_flutter_android/webview_flutter_android.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'package:permission_handler/permission_handler.dart';

class WebViewExample extends StatefulWidget {
  const WebViewExample({Key? key, required this.url}) : super(key: key);
  final String url;

  @override
  State<WebViewExample> createState() => _WebViewExampleState();
}

class _WebViewExampleState extends State<WebViewExample> {
  late final WebViewController controller;

  @override
  void initState() {
    super.initState();
    controller = WebViewController()
      ..setJavaScriptMode(JavaScriptMode.unrestricted)
      ..loadRequest(Uri.parse(widget.url))
      ..addJavaScriptChannel(
        'PayDala',
        onMessageReceived: (JavaScriptMessage message) {
          Map<String, dynamic> parsedJson = jsonDecode(message.message);
          WebchannelPayload payload = WebchannelPayload.fromJson(parsedJson);
          print(payload.type);
          if (payload.type == 'closePaydala') {
            Navigator.pop(context);
          }
          if(payload.type == 'sessionCreated' && payload.sessionId != null){
            print(payload.sessionId!);
            getProfilingData(payload.sessionId!);
          }
        },
      );

    final platformController = controller.platform;
    if (platformController is AndroidWebViewController) {
      platformController.setGeolocationPermissionsPromptCallbacks(
        onShowPrompt: (request) async {
          // request location permission
          final locationPermissionStatus =
              await Permission.locationWhenInUse.request();

          // return the response
          return GeolocationPermissionsResponse(
            allow: locationPermissionStatus == PermissionStatus.granted,
            retain: false,
          );
        },
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: WebViewWidget(
        controller: controller,
      ),
    );
  }

  Future<void> getProfilingData(String sessionId) async {
    String profileData = 'No Data';
    String? error;
    String orgId = '52whdrrv';
    String fpServer = 'h-sdk.online-metrix.net';
    print('SessionId: $sessionId');

    try {
      final result = await FlutterThreatmetrixModule()
              .getProfilingData(sessionId, orgId, fpServer) ??
          'No Data';
      profileData = result;
    } catch (e) {
      error = e.toString();
    }
  }
}
